import { useDictionaryStoreHook } from "@/store";
const { dicts } = useDictionaryStoreHook();

export const getTableConfig = (id: string) => {
  return {
    // 获取工序记录项信息信息
    jiluxiang: {
      url: `/api/v1/op/operationRecord`,
      column: [
        {
          label: "工序id",
          prop: "operationId",
          display: false,
          hide: true,
          value: id,
        },
        { label: "记录项", prop: "thName" },
        {
          label: "单位",
          prop: "unit",
          search: true,
          filterable: true,
          type: "select",
          dataType: "string",
          dicData: dicts.danwei_type,
          props: { label: "dictLabel", value: "dictValue" },
        },
        { label: "标准值", prop: "standard" },
        { label: "上限值", prop: "upper" },
        { label: "下限值", prop: "lower" },
      ],
    },

    FACTORY: {
      url: "/api/v1/base/workShop",
      column: [
        {
          label: "车间名称",
          prop: "name",
          search: true,
        },
        {
          label: "车间负责人",
          prop: "manager",
          rules: [
            {
              required: true,
              message: "请选择厂区负责人",
              trigger: "blur",
            },
          ],
          type: "select",
          dicUrl: import.meta.env.VITE_APP_BASE_API + "/api/v1/sys/user/list",
          dicMethod: "post",
          props: {
            label: "userName", // 下拉菜单显示的字段
            value: "userName", // 下拉菜单值的字段
          },
        },
        {
          label: "车间位置",
          prop: "position",
        },
        {
          label: "所属工厂",
          prop: "factoryName",
          display: false,
        },
        {
          label: "车间描述",
          prop: "remark",
        },
        {
          label: "创建人",
          prop: "creator",
          display: false,
        },
        {
          label: "创建时间",
          prop: "created",
          display: false,
        },
      ],
    },
  };
};

// 工艺工序组件路径的组件类别
interface comType {
  compentName: string;
  compentType: string;
}
export const comTypes: comType[] = [
  {
    compentName: "记录项",
    compentType: "jiluxiang",
  },
  {
    compentName: "物料采集",
    compentType: "wuliaocaiji",
  },
  {
    compentName: "ESOP",
    compentType: "ESOP",
  },
  {
    compentName: "点检",
    compentType: "dianjian",
  },
  {
    compentName: "设备记录",
    compentType: "shebeijilu",
  },
  {
    compentName: "紧固",
    compentType: "jingu",
  },
  {
    compentName: "调试配对",
    compentType: "tiaoshipipei",
  },
  {
    compentName: "铭牌绑定",
    compentType: "mingpai",
  },
  {
    compentName: "多媒体采集",
    compentType: "duomeiticaiji",
  },
];
